EXEC [__AddStoredProcInfo]
    /* StoredProc_Name         */ 'BowerPackages_CreateOrUpdatePackage',
    /* Internal_Indicator      */ 'N',
    /* ReturnType_Name         */ 'void',
    /* DataTableNames_Csv      */ NULL,
    /* OutputPropertyNames_Csv */ NULL,
    /* Description_Text        */ 'Creates a new Bower package in the system, or updates an existing one.'
GO

IF OBJECT_ID('[BowerPackages_CreateOrUpdatePackage]') IS NOT NULL DROP PROCEDURE [BowerPackages_CreateOrUpdatePackage]
GO

SET QUOTED_IDENTIFIER ON
GO

CREATE PROCEDURE [BowerPackages_CreateOrUpdatePackage]
(
	@Feed_Id INT,
	@Package_Name NVARCHAR(200),
	@Repository_Url VARCHAR(500)
)
AS
BEGIN

SET NOCOUNT ON

BEGIN TRY
	BEGIN TRANSACTION

	IF EXISTS(SELECT * FROM [BowerPackages] WITH (UPDLOCK) WHERE [Feed_Id] = @Feed_Id AND [Package_Name] = @Package_Name)
	BEGIN

		UPDATE [BowerPackages]
		   SET [Repository_Url] = @Repository_Url
		 WHERE [Feed_Id] = @Feed_Id
		   AND [Package_Name] = @Package_Name

		EXEC [Events_RaiseEvent] 'PKGMDF', @Feed_Id, 'Package_Name', @Package_Name

	END
	ELSE
	BEGIN

		INSERT INTO [BowerPackages]
		(
			[Feed_Id],
			[Package_Name],
			[Repository_Url],
			[Hit_Count]
		)
		VALUES
		(
			@Feed_Id,
			@Package_Name,
			@Repository_Url,
			0
		)

		EXEC [Events_RaiseEvent] 'PKGADD', @Feed_Id, 'Package_Name', @Package_Name

	END

	COMMIT
END TRY BEGIN CATCH
	IF XACT_STATE()<>0 ROLLBACK
	EXEC [HandleError]
END CATCH

END
GO

GRANT EXECUTE ON [BowerPackages_CreateOrUpdatePackage] TO [ProGetUser_Role]
GO